@@ -11,7 +11,7 @@ use List::MoreUtils qw(part);
 ###############################################################################
 # Version number.
 ###############################################################################
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 ###############################################################################
 # Use the '_arrayify()' method from DFV.
@@ -58,6 +58,26 @@ sub profile {
     return $self->{'profile'};
 }
 
+###############################################################################
+# Subroutine:   required()
+###############################################################################
+# Returns the list of "required" fields in the validation profile.
+###############################################################################
+sub required {
+    my $self = shift;
+    return _arrayify($self->{profile}{required});
+}
+
+###############################################################################
+# Subroutine:   optional()
+###############################################################################
+# Returns the list of "optional" fields in the validation profile.
+###############################################################################
+sub optional {
+    my $self = shift;
+    return _arrayify($self->{profile}{optional});
+}
+
 ###############################################################################
 # Subroutine:   only(@fields)
 # Parameters:   @fields     - List of fields to include
@@ -326,6 +346,10 @@ Data::FormValidator::Profile - Profile object for Data::FormValidator
       required  => [qw( some other thing )],
       } );
 
+  # query the optional/required fields in the profile
+  @optional = $profile->optional();
+  @required = $profile->required();
+
   # reduce the profile to just a limited set of fields
   $profile->only( qw(this that) );
 
@@ -434,6 +458,14 @@ Returns the actual profile, as a hash-ref. You need to call this method
 when you want to send the profile through to C<Data::FormValidator> to do
 data validation.
 
+=item B<required()>
+
+Returns the list of "required" fields in the validation profile.
+
+=item B<optional()>
+
+Returns the list of "optional" fields in the validation profile.
+
 =item B<only(@fields)>
 
 Reduces the profile so that it only contains information on the given list
